import { api } from '../api'
import { request } from 'umi'
/***********告警接口**************/

export interface RuleProps {
    field: string,
    condition: '>' | '>=' | '<' | '<=' | '=',
    value: string
}
export interface AddSysWarningRuleProps {
    // 1：默认规则；0：非默认规则；默认规则仅能创建一条
    defaultRule: 0 | 1,
    // 1：规则启用；0：规则禁用
    enable: 0 | 1,
    // 通知频率（分钟）,最少五分钟
    notifyFrequency: number,
    // 修改ID 
    ruleId: number,
    // 规则名称
    ruleName: string,
    // 规则列表
    rules: {
        rule: RuleProps[]
    }[],
    warningType: Array<'SMS' | 'DING_TALK'>
}
/** 设置预警 */
export async function addSysWarningRuleApi(data: AddSysWarningRuleProps) {
    return request(`${api}/adq/sysWarningRule/add`, {
        method: 'POST',
        data
    })
}
/** 修改预警 */
export async function editSysWarningRuleApi(data: AddSysWarningRuleProps) {
    return request(`${api}/adq/sysWarningRule/modify`, {
        method: 'POST',
        data
    })
}


/**
 * 告警规则下的广告列表
 * @param ruleId 
 * @returns 
 */
export async function getSysWarningRuleApi(ruleId: number) {
    return request(`${api}/adq/sysWarningRule/adList`, {
        method: 'GET',
        params: { ruleId }
    })
}

/**
 * 删除告警规则
 * @param ruleIds 
 * @returns 
 */
export async function delSysWarningRuleApi(ruleIds: string) {
    return request(`${api}/adq/sysWarningRule/delete/${ruleIds}`, {
        method: 'POST'
    })
}


export interface DelAdSysWarningRuleProps {
    accountId: number, 
    adgroupId: number, 
    campaignId: number
}
/**
 * 删除告警规则下的广告
 * @param data 
 * @returns 
 */
export async function delAdSysWarningRuleApi(data: DelAdSysWarningRuleProps[]) {
    return request(`${api}/adq/sysWarningRule/deleteAd`, {
        method: 'POST',
        data
    })
}

/**
 * 告警规则列表
 * @param params 
 * @returns 
 */
export async function getSysWarningRuleListApi(params: { ruleName?: string }) {
    return request(`${api}/adq/sysWarningRule/list`, {
        method: 'GET',
        params
    })
}

export interface AddAdsProps {
    accountId: number,
    adgroupId: number,
    campaignId: number
}
export interface ModifySysWarningRuleProps {
    addAds: AddAdsProps,
    ruleId: number
}
/**
 * 广告下设置规则
 * @param data 
 * @returns 
 */
export async function modifySysWarningRuleApi(data: ModifySysWarningRuleProps) {
    return request(`${api}/adq/sysWarningRule/modifyAd`, {
        method: 'POST',
        data
    })
}